Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(514)

Unified Diff: third_party/WebKit/Source/core/html/HTMLCanvasElement.cpp

Issue 2523673004: [NOT FOR COMMIT] Fully replace SkCanvas uses.
Patch Set: Support Android build. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/html/HTMLCanvasElement.cpp
diff --git a/third_party/WebKit/Source/core/html/HTMLCanvasElement.cpp b/third_party/WebKit/Source/core/html/HTMLCanvasElement.cpp
index 142aeed0e4480d3f0133ad2a143ae2408516d452..d44ed6eb83cd7a08cc9eda080e3425ea38283db1 100644
--- a/third_party/WebKit/Source/core/html/HTMLCanvasElement.cpp
+++ b/third_party/WebKit/Source/core/html/HTMLCanvasElement.cpp
@@ -72,6 +72,7 @@
#include "public/platform/Platform.h"
#include "public/platform/WebTraceLocation.h"
#include "public/platform/modules/offscreencanvas/offscreen_canvas_surface.mojom-blink.h"
+#include "skia/ext/cdl_canvas.h"
#include "wtf/CheckedNumeric.h"
#include "wtf/PtrUtil.h"
#include <math.h>
@@ -373,7 +374,7 @@ void HTMLCanvasElement::didDisableAcceleration() {
didDraw(FloatRect(0, 0, size().width(), size().height()));
}
-void HTMLCanvasElement::restoreCanvasMatrixClipStack(SkCanvas* canvas) const {
+void HTMLCanvasElement::restoreCanvasMatrixClipStack(CdlCanvas* canvas) const {
if (m_context)
m_context->restoreCanvasMatrixClipStack(canvas);
}
@@ -786,7 +787,7 @@ bool HTMLCanvasElement::shouldAccelerate(const IntSize& size) const {
if (RuntimeEnabledFeatures::displayList2dCanvasEnabled()) {
#if 0
// TODO(junov): re-enable this code once we solve the problem of recording
// GPU-backed images to an SkPicture for cross-context rendering crbug.com/490328
// If the compositor provides GPU acceleration to display list canvases, we
// prefer that over direct acceleration.
@@ -1052,7 +1053,7 @@ void HTMLCanvasElement::updateExternallyAllocatedMemory() const {
m_externallyAllocatedMemory = externallyAllocatedMemory;
}
-SkCanvas* HTMLCanvasElement::drawingCanvas() const {
+CdlCanvas* HTMLCanvasElement::drawingCanvas() const {
return buffer() ? m_imageBuffer->canvas() : nullptr;
}
@@ -1061,7 +1062,7 @@ void HTMLCanvasElement::disableDeferral(DisableDeferralReason reason) const {
m_imageBuffer->disableDeferral(reason);
}
-SkCanvas* HTMLCanvasElement::existingDrawingCanvas() const {
+CdlCanvas* HTMLCanvasElement::existingDrawingCanvas() const {
if (!hasImageBuffer())
return nullptr;
« no previous file with comments | « third_party/WebKit/Source/core/html/HTMLCanvasElement.h ('k') | third_party/WebKit/Source/core/html/HTMLVideoElement.h » ('j') | no next file with comments »
@@ -786,7 +787,7 @@ bool HTMLCanvasElement::shouldAccelerate(const IntSize& size) const {
#if 0
// TODO(junov): re-enable this code once we solve the problem of recording
- // GPU-backed images to an SkPicture for cross-context rendering crbug.com/490328
+ // GPU-backed images to an CdlPicture for cross-context rendering crbug.com/490328
// If the compositor provides GPU acceleration to display list canvases, we
// prefer that over direct acceleration.

Powered by Google App Engine
This is Rietveld 408576698